1.0.0 API documentation: GLM_EXT_matrix_uint3x3

| 1.0.0 API documentation

Typedefs
GLM_EXT_matrix_uint3x3
Stable extensions

## Typedefs
typedef mat< 3, 3, uint, defaultp > | umat3
| Unsigned integer 3x3 matrix. More...
typedef mat< 3, 3, uint, defaultp > | umat3x3
| Unsigned integer 3x3 matrix. More...

## Detailed Description

Include <glm/ext/matrix_uint3x3.hpp> to use the features of this extension.

Defines a number of matrices with integer types.

## Typedef Documentation

## ◆ umat3

typedef mat< 3, 3, uint, defaultp > umat3

Unsigned integer 3x3 matrix.

See also
  GLM_EXT_matrix_uint3x3
  GLM_GTC_matrix_integer

Definition at line 35 of file matrix_uint3x3.hpp.

## ◆ umat3x3

typedef mat< 3, 3, uint, defaultp > umat3x3

Unsigned integer 3x3 matrix.

See also
  GLM_EXT_matrix_uint3x3
  GLM_GTC_matrix_integer

Definition at line 30 of file matrix_uint3x3.hpp.